California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 034 - DEATH PENALTY REPEAL. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1345752 | JUSTICE CALIFORNIA, NO ON PROPOSITION 34 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344843 | A COMMITTEE IN SUPPORT OF PROPOSITION 34, SPONSORED BY ACLU OF NORTHERN CALIFORNIA | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350977 | SOUTHERN CALIFORNIA ALLIANCE OF LAW ENFORCEMENT COMMITTEE TO OPPOSE PROPOSITIONS 32 AND 34 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1341187 | YES ON 34, A COALITION OF JUSTICE ORGS. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1345802 | NO ON 34, PUBLIC SAFETY FIRST - KEEP THE DEATH PENALTY, SPONSORED BY CALIFORNIA PUBLIC SAFETY INSTITUTE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346266 | CALIFORNIANS FOR JUSTICE AND PUBLIC SAFETY, NO ON PROPOSITION 34 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | SUPPORT